.. _mypy: https://www.mypy-lang.org/
.. _pre-commit: https://pre-commit.com/
.. _pytest: https://docs.pytest.org/en/latest/
.. _Ruff: https://beta.ruff.rs/docs/
.. _scriv: https://scriv.readthedocs.io/en/latest/
.. _semver: https://semver.org/
.. _tox: https://tox.wiki/en/latest/
